Creating_Comparing_Reference_Curves_MUFModels

# Creating and Comparing Reference Curves Using MUFModels¶

The Microwave Uncertainty Framework (MUF) is a program developed at the National Institute of Standards and Technology (NIST) to deal with uncertainty propagation in high frequency electronics measurements. It has the ability to calculate uncertainties based on sensitivity analysis and Monte Carlo analysis. The package pyMez has many tools to deal independently with the MUF and data types associated with it. The majority of these are in the modules pyMez.Code.DataHandlers.MUFModels and pyMez.Code.Analysis.Sparameter. This notebook is an example of how to create a set of reference curves from the result of a MUF calculation. These results are typically organized as follows:

1. A file with the .meas extension that acts as a table of contents, it is a XML file that points to the files in directories that are normally directly below the .meas file with the naming scheme `<file_name>_Support` .
2. A nominal solution, located in the top directory `<file_name>_Support`. This is the solution where each parameter of the model describing the process is taken to be the mean. This is what is traditionally used as the "answer".
3. A directory for sensitivity results directly under the top directory `<file_name>_Support`. It follows the naming convention `<file_name>_Support\Covariance`. Inside of the directory there will be a file for every mechanism of uncertainty in the process. Each of these files is the result of assuming all but one of the mechanisms is the mean. One mechanism is assumed to be the mean + the standard uncertainty. The only way to associate the number of the file to the mechanism is via the .meas file.
4. A directory for Monte Carlo results directly under the top directory `<file_name>_Support`.It follows the naming convention `<file_name>_Support\MonteCarlo`. Inside of the directory there will be a file for each Monte Carlo trial. Each of these files is the result randomly selecting each parameter of the model describing the process from a distribution set by the user. All values change for every trial, there is currently no way to extract the chosen parameter values from the saved files.
5. A directory containing any needed presolution.

In [1]:

    # First we import pyMez
    from pyMez import *

    Importing pyMez, this should take roughly 30 seconds
    Importing Code.DataHandlers.GeneralModels
    It took 4.544 s to import Code.DataHandlers.GeneralModels
    Importing Code.DataHandlers.HTMLModels
    It took 0.722 s to import Code.DataHandlers.HTMLModels
    Importing Code.DataHandlers.NISTModels
    It took 15.571 s to import Code.DataHandlers.NISTModels
    Importing Code.DataHandlers.TouchstoneModels
    It took 0.01 s to import Code.DataHandlers.TouchstoneModels
    Importing Code.DataHandlers.XMLModels
    It took 0.395 s to import Code.DataHandlers.XMLModels
    Importing Code.DataHandlers.ZipModels
    It took 0.039 s to import Code.DataHandlers.ZipModels
    Importing Code.InstrumentControl.Experiments
    It took 2.137 s to import Code.InstrumentControl.Experiments
    Importing Code.InstrumentControl.Instruments
    It took 0.013 s to import Code.InstrumentControl.Instruments
    Importing Code.Utils.Names
    It took 0.013 s to import Code.Utils.Names
    It took 23.444 s to import all of the active modules

In [4]:

    # above there is a list of modules imported all of the modules are listed in the API_MODULES constant
    for module in sorted(API_MODULES.keys()):
        print("{0} import is set to {1}".format(module,API_MODULES[module]))

    Code.Analysis.Fitting import is set to False
    Code.Analysis.Interpolation import is set to False
    Code.Analysis.NISTUncertainty import is set to False
    Code.Analysis.Reports import is set to False
    Code.Analysis.SParameter import is set to False
    Code.Analysis.Transformations import is set to False
    Code.Analysis.Uncertainty import is set to False
    Code.DataHandlers.AbstractDjangoModels import is set to False
    Code.DataHandlers.GeneralModels import is set to True
    Code.DataHandlers.GraphModels import is set to False
    Code.DataHandlers.HTMLModels import is set to True
    Code.DataHandlers.MUFModels import is set to False
    Code.DataHandlers.NISTModels import is set to True
    Code.DataHandlers.RadiCALModels import is set to False
    Code.DataHandlers.StatistiCALModels import is set to False
    Code.DataHandlers.TouchstoneModels import is set to True
    Code.DataHandlers.Translations import is set to False
    Code.DataHandlers.XMLModels import is set to True
    Code.DataHandlers.ZipModels import is set to True
    Code.FrontEnds.AdvancedInterfaceFrame import is set to False
    Code.FrontEnds.BasicInterfaceFrame import is set to False
    Code.FrontEnds.EndOfDayDialog import is set to False
    Code.FrontEnds.GeneralInterfaceFrame import is set to False
    Code.FrontEnds.HTMLPanel import is set to False
    Code.FrontEnds.IEPanel import is set to False
    Code.FrontEnds.IPythonPanel import is set to False
    Code.FrontEnds.KeithleyIVPanel import is set to False
    Code.FrontEnds.MatplotlibWxPanel import is set to False
    Code.FrontEnds.ShellPanel import is set to False
    Code.FrontEnds.SimpleArbDBLowerInterfacePanel import is set to False
    Code.FrontEnds.SimpleLogLowerInterfacePanel import is set to False
    Code.FrontEnds.StyledTextCtrlPanel import is set to False
    Code.FrontEnds.VisaDialog import is set to False
    Code.FrontEnds.WxDialogFunctions import is set to False
    Code.FrontEnds.WxHTML2Panel import is set to False
    Code.FrontEnds.XMLEditPanel import is set to False
    Code.FrontEnds.XMLGeneral import is set to False
    Code.InstrumentControl.Experiments import is set to True
    Code.InstrumentControl.Instruments import is set to True
    Code.Utils.Alias import is set to False
    Code.Utils.DjangoUtils import is set to False
    Code.Utils.GetMetadata import is set to False
    Code.Utils.HPBasicUtils import is set to False
    Code.Utils.HelpUtils import is set to False
    Code.Utils.Names import is set to True
    Code.Utils.PerformanceUtils import is set to False
    Code.Utils.pyMezUnitTest import is set to False

In [10]:

    # now we want to import pyMez.Code.DataHandlers.MUFModels, and pyMez.Code.Analysis.Sparameter
    # Because pyMez.Code.Analysis.SParameter contains a lot of references to other code it takes a bit to import
    from pyMez.Code.DataHandlers.MUFModels import *
    from pyMez.Code.Analysis.SParameter import *

In [6]:

    # to import the nominal file we use the SNP data type
    # in module pyMez.Code.DataHandlers.TouchstoneModels, because it is an s2p file
    nominal_path=os.path.join(os.getcwd(),
                              "MUFModels_Example_Files/WR15_Line_5079_WR15_20180223_002_Support",
                              "WR15_Line_5079_WR15_20180223_002_0.s2p")
    nominal=SNP(nominal_path)

In [8]:

    # to see a basic plot use the method .show()
    nominal.show();

In [11]:

    # if we want a curve with uncertanties we can use
    covariance_directory=os.path.join(os.getcwd(),"MUFModels_Example_Files\WR15_Line_5079_WR15_20180223_002_Support\Covariance")
    sensitivity=create_sensitivity_reference_curve(nominal_file_path=nominal_path,
                                                   sensitivity_directory=covariance_directory)

In [13]:

    # now to plot the curve we use plot_reference_curve
    # note we use this instead of a built in show because the class of the reference curve is a general AsciiDataTable
    plot_reference_curve(sensitivity);

In [14]:

    # to create a curve of the statistically biased mean and the montecarlo uncertainties,
    #this tends to be slow for large montecarlo sets
    montecarlo_directory=os.path.join(os.getcwd(),r"MUFModels_Example_Files\WR15_Line_5079_WR15_20180223_002_Support\MonteCarlo")
    montecarlo=create_monte_carlo_reference_curve(monte_carlo_directory=montecarlo_directory)

In [15]:

    plot_reference_curve(montecarlo);

In [16]:

    # each of these commands also has a format option that allows you to plot it in MA, DB, or RI
    sensitivity_MA=create_sensitivity_reference_curve(nominal_file_path=nominal_path,
                                                   sensitivity_directory=covariance_directory,
                                                     format="MA")
    montecarlo_MA=create_monte_carlo_reference_curve(monte_carlo_directory=montecarlo_directory,
                                                    format="MA")
    plot_reference_curve(sensitivity_MA);
    plot_reference_curve(montecarlo_MA);

In [17]:

    # now it is typicall to compare one of the curves say the mean amplitude of magS21 with the statistical bias one
    plt.plot(montecarlo_MA["Frequency"],np.array(montecarlo_MA["magS21"])-np.array(sensitivity_MA["magS21"]))
    plt.show();

In [18]:

    # Each of the reference tables is a AsciiDataTable, effectively a csv type class. You can retrieve
    # a list of values by using the column name as an  index
    montecarlo_MA.column_names

Out[18]:

    ['Frequency',
     'magS11',
     'argS11',
     'magS21',
     'argS21',
     'magS12',
     'argS12',
     'magS22',
     'argS22',
     'umagS11',
     'uargS11',
     'umagS21',
     'uargS21',
     'umagS12',
     'uargS12',
     'umagS22',
     'uargS22']

In [21]:

    # to add error bars you can use plt.errorbar
    plt.errorbar(x=montecarlo_MA["Frequency"],y=montecarlo_MA["magS21"],yerr=montecarlo_MA["umagS21"],label="MonteCarlo")
    plt.errorbar(x=sensitivity_MA["Frequency"],y=sensitivity_MA["magS21"],yerr=sensitivity_MA["umagS21"],label="Sensitivity")
    plt.ylabel("S21")
    plt.xlabel("Frequency (GHz)")
    plt.legend()
    plt.show()

In [26]:

    #fill_between is also useful
    sensitivity_y=np.array( sensitivity_MA["magS21"])
    sensitivity_err=np.array( sensitivity_MA["umagS21"])
    plt.plot(sensitivity_MA["Frequency"],sensitivity_y, label="Sensitivity")
    plt.fill_between(sensitivity_MA["Frequency"], sensitivity_y - sensitivity_err, sensitivity_y + sensitivity_err,
                            color='blue',
                            alpha=.25,
                            edgecolor='black')

    montecarlo_y=np.array( montecarlo_MA["magS21"])
    montecarlo_err=np.array( montecarlo_MA["umagS21"])
    plt.plot(montecarlo_MA["Frequency"],montecarlo_y, label="MonteCarlo")
    plt.fill_between(montecarlo_MA["Frequency"], montecarlo_y - montecarlo_err, montecarlo_y + montecarlo_err,
                            color='red',
                            alpha=.25,
                            edgecolor='black')
    plt.ylabel("S21")
    plt.xlabel("Frequency (GHz)")
    plt.legend()
    plt.show()

In [29]:

    # to inspect the .meas (xml) file directly we can use
    measurement_path=os.path.join(os.getcwd(),r"MUFModels_Example_Files\WR15_Line_5079_WR15_20180223_002.meas")
    measurement=MUFMeasurement(measurement_path)

In [30]:

    # to look at the mechanism names versus sensitivity names
    measurement.get_name_parameter_dictionary()

Out[30]:

    {'WR15_Line_5079_WR15_20180223_002_1': 'WR15_Width',
     'WR15_Line_5079_WR15_20180223_002_2': 'WR15_Height',
     'WR15_Line_5079_WR15_20180223_002_3': 'Line5079_Length',
     'WR15_Line_5079_WR15_20180223_002_4': 'Line4909_Length'}

In [31]:

    # to look at the pointers for the sensitivty
    measurement.get_covariance_dictionary()

Out[31]:

    [{'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\Covariance\\WR15_Line_5079_WR15_20180223_002_1.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_1',
      'parameter_location': 'C:\\Share\\WR15_OML_MUF_20180313\\LRL_1\\Models\\Parameters\\WR15_Width.parameter'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\Covariance\\WR15_Line_5079_WR15_20180223_002_2.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_2',
      'parameter_location': 'C:\\Share\\WR15_OML_MUF_20180313\\LRL_1\\Models\\Parameters\\WR15_Height.parameter'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\Covariance\\WR15_Line_5079_WR15_20180223_002_3.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_3',
      'parameter_location': 'C:\\Share\\WR15_OML_MUF_20180313\\LRL_1\\Models\\Parameters\\Line5079_Length.parameter'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\Covariance\\WR15_Line_5079_WR15_20180223_002_4.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_4',
      'parameter_location': 'C:\\Share\\WR15_OML_MUF_20180313\\LRL_1\\Models\\Parameters\\Line4909_Length.parameter'}]

In [32]:

    # to look at the pointers for the montecarlo
    measurement.get_montecarlo_dictionary()

Out[32]:

    [{'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_1.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_1'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_2.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_2'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_3.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_3'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_4.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_4'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_5.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_5'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_6.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_6'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_7.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_7'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_8.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_8'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_9.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_9'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_10.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_10'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_11.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_11'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_12.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_12'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_13.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_13'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_14.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_14'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_15.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_15'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_16.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_16'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_17.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_17'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_18.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_18'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_19.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_19'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_20.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_20'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_21.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_21'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_22.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_22'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_23.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_23'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_24.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_24'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_25.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_25'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_26.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_26'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_27.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_27'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_28.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_28'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_29.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_29'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_30.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_30'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_31.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_31'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_32.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_32'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_33.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_33'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_34.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_34'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_35.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_35'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_36.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_36'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_37.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_37'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_38.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_38'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_39.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_39'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_40.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_40'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_41.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_41'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_42.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_42'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_43.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_43'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_44.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_44'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_45.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_45'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_46.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_46'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_47.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_47'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_48.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_48'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_49.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_49'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_50.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_50'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_51.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_51'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_52.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_52'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_53.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_53'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_54.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_54'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_55.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_55'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_56.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_56'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_57.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_57'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_58.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_58'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_59.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_59'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_60.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_60'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_61.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_61'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_62.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_62'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_63.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_63'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_64.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_64'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_65.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_65'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_66.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_66'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_67.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_67'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_68.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_68'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_69.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_69'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_70.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_70'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_71.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_71'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_72.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_72'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_73.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_73'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_74.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_74'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_75.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_75'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_76.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_76'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_77.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_77'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_78.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_78'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_79.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_79'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_80.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_80'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_81.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_81'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_82.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_82'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_83.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_83'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_84.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_84'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_85.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_85'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_86.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_86'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_87.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_87'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_88.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_88'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_89.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_89'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_90.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_90'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_91.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_91'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_92.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_92'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_93.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_93'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_94.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_94'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_95.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_95'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_96.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_96'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_97.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_97'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_98.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_98'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_99.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_99'},
     {'location': 'C:\\Share\\WR15_VDI_MUF_20180316\\LRL_1\\DUTs\\WR15_Line_5079_WR15_20180223_002_Support\\MonteCarlo\\WR15_Line_5079_WR15_20180223_002_100.s2p',
      'name': 'WR15_Line_5079_WR15_20180223_002_100'}]